@@ -28,7 +28,7 @@
 
 from inspect import getfullargspec, getcallargs
 from collections import Callable, Iterable, Mapping, Sequence, Iterator
-from functools import reduce
+from functools import reduce, wraps
 from itertools import count
 from operator import __and__
 
@@ -456,7 +456,8 @@ def dispatch(spec, value,
 
 def checked(func):
     '''
-    A decorator that adds type checking to a function or method.
+    A decorator that adds **runtime verification of type annotations** to a
+    function or method.
 
       >>> @checked
       ... def str_len(s:str) -> int:
@@ -475,15 +476,17 @@ def checked(func):
         ...
       TypeError: Unexpected type or value: <class 'int'>/wrong
     '''
+    @wraps(func)
     def wrapper(*args, **kargs):
         callargs = getcallargs(func, *args, **kargs)
-        annotations = getfullargspec(func).annotations
+        annotations = dict(getfullargspec(func).annotations)
         rspec = annotations.pop('return', None)
         for name in annotations:
             spec = annotations[name]
             value = callargs.get(name, None)
             validate(spec, value)
         result = func(*args, **kargs)
+        print(rspec, result)
         validate(rspec, result)
         return result
     return wrapper
